Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(774)

Unified Diff: components/history/core/browser/history_service.h

Issue 1370493002: Enable history counting for time ranges. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Addressed comments. Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/history/core/browser/history_service.h
diff --git a/components/history/core/browser/history_service.h b/components/history/core/browser/history_service.h
index 56fa1140c7252a5e9c780e0620d2bff7dfede1a7..62267e1b138f8bc0a143cd12bd2ef32f4de211d7 100644
--- a/components/history/core/browser/history_service.h
+++ b/components/history/core/browser/history_service.h
@@ -344,13 +344,15 @@ class HistoryService : public syncer::SyncableService, public KeyedService {
// Statistics ----------------------------------------------------------------
// Gets the number of URLs as seen in chrome://history with infinite date
// range. If a URL is visited in multiple days, the URL is counted once for
// each day. For determination of the date, timestamps are converted to dates
// using local time.
typedef base::Callback<void(HistoryCountResult)> GetHistoryCountCallback;
base::CancelableTaskTracker::TaskId GetHistoryCount(
+ const base::Time& begin_time,
+ const base::Time& end_time,
const GetHistoryCountCallback& callback,
base::CancelableTaskTracker* tracker);
@@ -344,13 +344,15 @@ class HistoryService : public syncer::SyncableService, public KeyedService {
// Statistics ----------------------------------------------------------------
- // Gets the number of URLs as seen in chrome://history with infinite date
- // range. If a URL is visited in multiple days, the URL is counted once for
- // each day. For determination of the date, timestamps are converted to dates
- // using local time.
+ // Gets the number of URLs as seen in chrome://history within the time range
+ // [|begin_time|, |end_time|). Each URL is counted only once per day. For
+ // determination of the date, timestamps are converted to dates using local
+ // time.
typedef base::Callback<void(HistoryCountResult)> GetHistoryCountCallback;
base::CancelableTaskTracker::TaskId GetHistoryCount(

Powered by Google App Engine
This is Rietveld 408576698